package com.gxzc.zen

import com.baomidou.mybatisplus.generator.AutoGenerator
import com.baomidou.mybatisplus.generator.config.DataSourceConfig
import com.baomidou.mybatisplus.generator.config.GlobalConfig
import com.baomidou.mybatisplus.generator.config.PackageConfig
import com.baomidou.mybatisplus.generator.config.StrategyConfig
import com.baomidou.mybatisplus.generator.config.rules.DbType
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy

/**
 *
 * @author NorthLan
 * @date 2018/1/24
 * @url https://noahlan.me
 */
class Generator{
    fun main(args: Array<String>) {
        val mpg = AutoGenerator()

        // 全局配置
        val gc = GlobalConfig()
        with(gc) {
            outputDir = "D://Test" // 输出根目录
            isFileOverride = true // 覆盖
            isActiveRecord = false // ActiveRecord (不适用)
            isOpen = true // 打开输出目录
            author = "NorthLan" // 作者
            isKotlin = true // 生成kotlin代码

            isEnableCache = false // xml二级缓存配置
            isBaseResultMap = true // xml BaseResultMap
            isBaseColumnList = false // xml ColumnList
            mapperName = "%sMapper" // Mapper命名
            xmlName = "%sMapper" // xml名
            serviceName = "I%sService" // service名
            serviceImplName = "%sServiceImpl" // service实现类名
        }
        mpg.globalConfig = gc

        // 数据源
        val dataSource = DataSourceConfig()
        with(dataSource) {
            dbType = DbType.MYSQL
            // typeConvert
            driverName = "com.mysql.jdbc.Driver"
            username = "root"
            password = "root"
            url = "jdbc:mysql://127.0.0.1:3306/rest?characterEncoding=utf8"
        }
        mpg.dataSource = dataSource

        // 策略配置
        val strategy = StrategyConfig()
        with(strategy) {
            setDbColumnUnderline(true)
            isCapitalMode = false
            naming = NamingStrategy.underline_to_camel
            //            setTablePrefix()
            superEntityClass = "com.gxzc.zen.persistence.BaseModel"
            setSuperEntityColumns("id", "createBy", "createTime", "updateBy", "updateTime", "remark", "enable")
            superMapperClass = "com.gxzc.zen.persistence.BaseMapper"
            superServiceClass = "com.gxzc.zen.persistence.BaseService"
            superServiceImplClass = "com.baomidou.mybatisplus.service.impl.ServiceImpl"
//            superControllerClass = ""
            isEntityBooleanColumnRemoveIsPrefix = true
            logicDeleteFieldName = "enable"
//            setExclude("")
            setInclude("user")
        }
        mpg.strategy = strategy

        // 包配置
        val pc = PackageConfig()
        with(pc) {
            parent = "com.gxzc.zen.persistence"
//            moduleName = "test"
            entity = "model"
            mapper = "mapper"
            service = "service"
            serviceImpl = "service.impl"
            controller = "controller"
        }
        mpg.packageInfo = pc

        mpg.cfg

        mpg.execute()
    }
}
